@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2016-12-02'; # DATE
-our $VERSION = '1.64'; # VERSION
+our $DATE = '2016-12-15'; # DATE
+our $VERSION = '1.65'; # VERSION
 
 use 5.010001;
 use strict;
@@ -89,6 +89,11 @@ has use_utf8 => (
     },
 );
 
+has default_dry_run => (
+    is=>'rw',
+    default => 0,
+);
+
 # role: requires 'hook_after_get_meta'
 # role: requires 'hook_format_row'
 # role: requires 'default_prompt_template'
@@ -741,8 +746,8 @@ sub _parse_argv1 {
 
         require Getopt::Long;
         my $old_go_conf = Getopt::Long::Configure(
-            'pass_through', 'no_ignore_case', 'bundling', 'no_auto_abbrev',
-            'no_getopt_compat', 'gnu_compat');
+            'pass_through', 'no_ignore_case', 'no_auto_abbrev',
+            'no_getopt_compat', 'gnu_compat', 'bundling');
         my $co = $self->common_opts // {};
         for my $k (keys %$co) {
             push @go_spec, $co->{$k}{getopt} => sub {
@@ -826,7 +831,8 @@ sub _parse_argv1 {
     }
 
     # also set dry-run on environment
-    $r->{dry_run} = 1 if $ENV{DRY_RUN};
+    $r->{dry_run} = defined($ENV{DRY_RUN}) ? ($ENV{DRY_RUN} ? 1:0) :
+        $self->default_dry_run;
 
     $r->{_parse_argv1_done} = 1;
 }
@@ -1450,7 +1456,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.64 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-12-02.
+This document describes version 1.65 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-12-15.
 
 =head1 DESCRIPTION
 
@@ -2257,6 +2263,11 @@ C<cmdline.skip_format> set to true.
 Whether or not to set utf8 flag on output. If undef, will default to UTF8
 environment. If that is also undef, will default to 0.
 
+=head2 default_dry_run => bool (default: 0)
+
+If set to 1, then dry-mode will be turned on by default unless user uses
+DRY_RUN=0 or C<--no-dry-run>.
+
 =head1 METHODS
 
 =head2 $cmd->run() => ENVRES
