@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2016-12-02'; # DATE
-our $VERSION = '1.64'; # VERSION
+our $DATE = '2016-12-15'; # DATE
+our $VERSION = '1.65'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -346,13 +346,20 @@ sub hook_after_get_meta {
     require Perinci::Object;
     if (Perinci::Object::risub($r->{meta})->can_dry_run) {
         $self->common_opts->{dry_run} = {
-            getopt  => 'dry-run',
-            summary => "Run in simulation mode (also via DRY_RUN=1)",
+            getopt  => $self->default_dry_run ? 'dry-run!' : 'dry-run',
+            summary => $self->default_dry_run ?
+                "Disable simulation mode (also via DRY_RUN=0)" :
+                "Run in simulation mode (also via DRY_RUN=1)",
             handler => sub {
                 my ($go, $val, $r) = @_;
-                $log->debugf("[pericmd] Dry-run mode is activated");
-                $r->{dry_run} = 1;
-                #$ENV{VERBOSE} = 1;
+                if ($val) {
+                    $log->debugf("[pericmd] Dry-run mode is activated");
+                    $r->{dry_run} = 1;
+                    #$ENV{VERBOSE} = 1;
+                } else {
+                    $log->debugf("[pericmd] Dry-run mode is deactivated");
+                    $r->{dry_run} = 0;
+                }
             },
         };
     }
@@ -505,7 +512,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 1.64 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2016-12-02.
+This document describes version 1.65 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2016-12-15.
 
 =head1 SYNOPSIS
 
